package com.myasto.jsbridge;

import android.util.Log;
import android.webkit.JavascriptInterface;
import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.myasto.views.RatesView;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.params.AuthPolicy;
import org.apache.http.client.params.ClientPNames;
import org.apache.http.client.params.HttpClientParams;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.params.BasicHttpParams;
import org.apache.http.params.HttpConnectionParams;
import org.apache.http.params.HttpParams;
import org.apache.http.util.EntityUtils;
import org.w3c.dom.*;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;


public class JsCallBack {

    private static final int SERVER_CONNECTION_TIMEOUT = 60000;

    private HttpClient client =  createHttpClient(SERVER_CONNECTION_TIMEOUT);

    String LOG = "JsCallBack";

    RatesView ratesView;

    public JsCallBack() {
    }

    public JsCallBack(RatesView ratesView) {
        this.ratesView = ratesView;
    }

    @JavascriptInterface
    public String getJson()  {

        String xmlData =  getXmlString();
        xmlData = xmlData.replace("<?xml version=\"1.0\" encoding=\"UTF-8\"?>","");
        JsonArray ratesArray  = createJsonFromXml(xmlData );
        Gson gson = new Gson();
        return gson.toJson(ratesArray);
    }

    @JavascriptInterface
    public void setView(int val){
        this.ratesView.setView(val);
    }



    public  JsonArray createJsonFromXml( String xmlData ) {
        JsonArray ratesArray = new JsonArray();

        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        DocumentBuilder builder = null;
        try {
            builder = factory.newDocumentBuilder();

        Reader reader = new StringReader(xmlData);
        Document dom = builder.parse(new InputSource(reader));
        Element root = dom.getDocumentElement();
        NodeList items = root.getElementsByTagName("Rate");
        for (int i=0;i<items.getLength();i++){
            Node item = items.item(i);
            NodeList properties = item.getChildNodes();
            JsonObject jObj  = new JsonObject();
            NamedNodeMap attributes = (NamedNodeMap)item.getAttributes();
            for (int g = 0; g < attributes.getLength(); g++) {
                Attr attribute = (Attr)attributes.item(g);
                System.out.println("Symbol"+" : "+attribute.getValue());
                jObj.addProperty("Symbol",attribute.getValue());
            }
            for (int j=0;j<properties.getLength();j++){
                Node property = properties.item(j);
                String name = property.getNodeName();

                if(property.getFirstChild() !=null) {
                    String value =  property.getFirstChild().getNodeValue();
                    System.out.println(name+" : "+value);
                     if (name.equals("Bid"))  {
                         jObj.addProperty("Bid", value);
                     }
                    else   if (name.equals("Ask"))  {
                         jObj.addProperty("Ask", value);
                     }

                    else   if (name.equals("High"))  {
                         jObj.addProperty("High", value);
                     }

                    else   if (name.equals("Low"))  {
                         jObj.addProperty("Low", value);
                     }
                     else   if (name.equals("Direction"))  {
                         jObj.addProperty("Direction", value);
                     }
                     else   if (name.equals("Last"))  {
                         jObj.addProperty("Last", value);
                     }

                    else continue;

                }

            }

            ratesArray.add(jObj);
        }

        } catch (ParserConfigurationException e) {
            e.printStackTrace();
        } catch (SAXException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (IOException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }



        return ratesArray;
    }


    public String getXmlString() {

        String rawXml = null;

        try {

            rawXml =  retrieve( "http://rates.fxcm.com/RatesXML");

        } catch (Exception e) {

            System.out.println("Error: " + e.getMessage());


        }

        return rawXml;
    }

    public String retrieve(String url) {

        HttpGet getRequest = new HttpGet(url);

        try {

            HttpResponse getResponse = client.execute(getRequest);
            final int statusCode = getResponse.getStatusLine().getStatusCode();

            if (statusCode != HttpStatus.SC_OK) {
                return null;
            }

            HttpEntity getResponseEntity = getResponse.getEntity();

            if (getResponseEntity != null) {
                return EntityUtils.toString(getResponseEntity);
            }

        }
        catch (IOException e) {
            getRequest.abort();
            System.out.println(getClass().getSimpleName()+"Error for URL " + url+ e);
        }

        return null;

    }

    private  HttpClient createHttpClient(int timeout) {
        // configure connection
        HttpParams params = new BasicHttpParams();
        HttpConnectionParams.setConnectionTimeout(params, timeout);
        HttpConnectionParams.setSoTimeout(params, timeout);
        // support redirecting to handle http: => https: transition
        HttpClientParams.setRedirecting(params, true);
        // support authenticating
        HttpClientParams.setAuthenticating(params, true);
        // if possible, bias toward digest auth (may not be in 4.0 beta 2)
        List<String> authPref = new ArrayList<String>();
        authPref.add(AuthPolicy.DIGEST);
        authPref.add(AuthPolicy.BASIC);
        // does this work in Google's 4.0 beta 2 snapshot?
        // params.setParameter("http.auth-target.scheme-pref", authPref);

        // setup client
        HttpClient httpclient = new DefaultHttpClient(params);
        httpclient.getParams().setParameter(ClientPNames.MAX_REDIRECTS, 1);
        httpclient.getParams().setParameter(ClientPNames.ALLOW_CIRCULAR_REDIRECTS, true);

        return httpclient;
    }


}
