package com.myasto.views;


import android.app.ListActivity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ListView;
import com.google.code.rome.android.repackaged.com.sun.syndication.feed.synd.SyndEntry;
import com.google.code.rome.android.repackaged.com.sun.syndication.feed.synd.SyndFeed;
import com.google.code.rome.android.repackaged.com.sun.syndication.io.FeedException;
import com.google.code.rome.android.repackaged.com.sun.syndication.io.SyndFeedInput;
import com.google.code.rome.android.repackaged.com.sun.syndication.io.XmlReader;
import com.myasto.R;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

public class AtomNewsView extends ListActivity {

    private ProgressDialog progressDialog;
    private boolean destroyed = false;
    private SyndFeed feed;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setTitle(null);

        // initiate the asynchronous network request
        new DownloadAtomFeedTask().execute();
    }

    @Override
    public void onStart() {
        super.onStart();
    }


    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {
        if (feed == null) {
            return;
        }

        SyndEntry entry = (SyndEntry) feed.getEntries().get(position);
        String link = entry.getLink();
        Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(link));
        this.startActivity(intent);
    }

    private void refreshAtomFeed(SyndFeed feed) {
        this.feed = feed;

        if (feed == null) {
            return;
        }

        setTitle(feed.getTitle());

        SyndFeedListAdapter adapter = new SyndFeedListAdapter(this, feed);

        setListAdapter(adapter);
    }

    private class DownloadAtomFeedTask extends AsyncTask<Void, Void, SyndFeed> {

        @Override
        protected void onPreExecute() {
            // before the network request begins, show a progress indicator
            showLoadingProgressDialog();
        }

        @Override
        protected SyndFeed doInBackground(Void... params) {

            SyndFeed feed = null;


            // initial url
            final String url = getString(R.string.atom_feed_istanbul);
            try {
                URL feedUrl = new URL(url);
                SyndFeedInput input = new SyndFeedInput();
                feed = input.build(new XmlReader(feedUrl));
            } catch (MalformedURLException e) {
                e.printStackTrace();
            } catch (FeedException e) {
                e.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }

          return feed;
        }



        @Override
        protected void onPostExecute(SyndFeed feed) {
            // hide the progress indicator when the network request is complete
            dismissProgressDialog();

            // return the feed list
            refreshAtomFeed(feed);
        }
    }



    public void showLoadingProgressDialog() {
        this.showProgressDialog("Loading. Please wait...");
    }

    public void showProgressDialog(CharSequence message) {
        if (progressDialog == null) {
            progressDialog = new ProgressDialog(this);
            progressDialog.setIndeterminate(true);
        }

        progressDialog.setMessage(message);
        progressDialog.show();
    }

    public void dismissProgressDialog() {
        if (progressDialog != null && !destroyed) {
            progressDialog.dismiss();
        }
    }

    // ***************************************
    // Activity methods
    // ***************************************
    @Override
    protected void onDestroy() {
        super.onDestroy();
        destroyed = true;


    }


}